.capture_promptAny(fnam, type, package, final, ..., methods)
.capture_installed_help(fnam, type = NULL, package = NULL,
suffix = NULL)fnam to
obtain the complete name of the help topic, e.g. "-class",
"-method".try-error object otherwisereprompt. It falls back
to them when only when the user has not supplied an Rd file in the
call.
Note that for editing it is preferable to use the source Rd files
(when available), since some hard coded information in the installed
help may have been produced by more elaborated code in the Rd sources,
most notably Sweave expressions.
.capture_promptAny is used to generate documentation when none
has been supplied by the user or loaded in the session.
.capture_promptAny parses fnam to obtain the name of the
object and the type of the required documentation (function, methods,
class), then generates it. Currently this is done with the built in
functions of the promptXXX family.
.capture_installed_help does exactly that --- it captures the
currently installed requested help topic. This function needs clean
up. It was originally written at a time when both the old and new help
formats where co-existing.##---- Should be DIRECTLY executable !! ----Run the code above in your browser using DataLab