Learn R Programming

Rdpack (version 0.4-4)

Rdo_is_newline: Check if an Rd fragment represents a newline character

Description

Check if an Rd fragment represents a newline character

Usage

Rdo_is_newline(rdo)

Arguments

rdo
an Rd object

Details

This is a utility function that may be used to tidy up Rd objects. It returns TRUE if the Rd object represents a newline character, i.e. it is a character vector of length one containing the string "". Attributes are ignored. Otherwise it returns FALSE. TRUE or FALSE [object Object]RdoBuild