inspect_clmethods(rdo, final = TRUE)
inspect_signatures(rdo, package = NULL, sec = "Methods")inspect_signatures inspects signatures in
documentation of methods of a function. inspect_clmethods
inspects signatures in documentation of a class.
inspect_signatures was written before
inspect_clmethods() and was geared towards using existing code
for ordinary functions (mainly parse_usage_text().
If new methods are found, the functions add entries for them in the Rd
object rdo.
If rdo documents methods that do not exist, a message inviting
the user to remove them manually is printed but the offending entries
remain the object.